@@ -67,6 +67,9 @@ LOCAL_CACERT_PATH = '/etc/pki/ca-trust/source/anchors/cm-local-ca.pem'
 # Swift via SwiftPlanStorageBackend to identify them from other containers
 TRIPLEO_META_USAGE_KEY = 'x-container-meta-usage-tripleo'
 
+# 30 minutes maximum to build the child layers at the same time.
+BUILD_TIMEOUT = 1800
+
 #: List of names of parameters that contain passwords
 PASSWORD_PARAMETER_NAMES = (
     'AdminPassword',
@@ -119,6 +122,7 @@ PASSWORD_PARAMETER_NAMES = (
     'PacemakerRemoteAuthkey',
     'PankoPassword',
     'PcsdPassword',
+    'PlacementPassword',
     'RpcPassword',
     'NotifyPassword',
     'RabbitCookie',
@@ -199,3 +203,5 @@ ANSIBLE_ERRORS_FILE = 'ansible-errors.json'
 DEPLOYMENT_STATUS_FILE = 'deployment_status.yaml'
 
 MISTRAL_WORK_DIR = '/var/lib/mistral'
+
+EXCLUSIVE_NEUTRON_DRIVERS = ['ovn', 'openvswitch']
