@@ -30,11 +30,6 @@ import tempfile
 import tenacity
 import yaml
 
-import docker
-try:
-    from docker import APIClient as Client
-except ImportError:
-    from docker import Client
 from oslo_concurrency import processutils
 from oslo_log import log as logging
 from tripleo_common.actions import ansible
@@ -53,6 +48,8 @@ SECURE_REGISTRIES = (
     'registry-1.docker.io',
 )
 
+NO_VERIFY_REGISTRIES = ()
+
 CLEANUP = (
     CLEANUP_FULL, CLEANUP_PARTIAL, CLEANUP_NONE
 ) = (
@@ -115,7 +112,6 @@ class ImageUploadManager(BaseImageManager):
             config_files = []
         super(ImageUploadManager, self).__init__(config_files)
         self.uploaders = {
-            'docker': DockerImageUploader(),
             'skopeo': SkopeoImageUploader(),
             'python': PythonImageUploader()
         }
@@ -137,6 +133,9 @@ class ImageUploadManager(BaseImageManager):
             raise ImageUploaderException('Unknown image uploader type')
         return self.uploaders[uploader]
 
+    def get_uploader(self, uploader):
+        return self.uploader(uploader)
+
     def get_push_destination(self, item):
         push_destination = item.get('push_destination')
         if not push_destination:
@@ -181,18 +180,12 @@ class ImageUploadManager(BaseImageManager):
 
         return upload_images  # simply to make test validation easier
 
-    def get_uploader(self, uploader):
-        if uploader == 'docker':
-            return DockerImageUploader()
-        if uploader == 'skopeo':
-            return SkopeoImageUploader()
-        raise ImageUploaderException('Unknown image uploader type')
-
 
 class BaseImageUploader(object):
 
     mirrors = {}
     insecure_registries = set()
+    no_verify_registries = set(NO_VERIFY_REGISTRIES)
     secure_registries = set(SECURE_REGISTRIES)
     export_registries = set()
     push_registries = set()
@@ -206,6 +199,8 @@ class BaseImageUploader(object):
     @classmethod
     def init_registries_cache(cls):
         cls.insecure_registries.clear()
+        cls.no_verify_registries.clear()
+        cls.no_verify_registries.update(NO_VERIFY_REGISTRIES)
         cls.secure_registries.clear()
         cls.secure_registries.update(SECURE_REGISTRIES)
         cls.mirrors.clear()
@@ -221,7 +216,7 @@ class BaseImageUploader(object):
     @classmethod
     def run_modify_playbook(cls, modify_role, modify_vars,
                             source_image, target_image, append_tag,
-                            container_build_tool='docker'):
+                            container_build_tool='buildah'):
         vars = {}
         if modify_vars:
             vars.update(modify_vars)
@@ -304,7 +299,6 @@ class BaseImageUploader(object):
         else:
             return True
 
-    @classmethod
     @tenacity.retry(  # Retry up to 5 times with jittered exponential backoff
         reraise=True,
         retry=tenacity.retry_if_exception_type(
@@ -313,10 +307,14 @@ class BaseImageUploader(object):
         wait=tenacity.wait_random_exponential(multiplier=1, max=10),
         stop=tenacity.stop_after_attempt(5)
     )
-    def authenticate(cls, image_url, username=None, password=None):
-        image, tag = cls._image_tag_from_url(image_url)
-        url = cls._build_url(image_url, path='/')
+    def authenticate(self, image_url, username=None, password=None):
+        netloc = image_url.netloc
+        image, tag = self._image_tag_from_url(image_url)
+        self.is_insecure_registry(netloc)
+        url = self._build_url(image_url, path='/')
+
         session = requests.Session()
+        session.verify = (netloc not in self.no_verify_registries)
         r = session.get(url, timeout=30)
         LOG.debug('%s status code %s' % (url, r.status_code))
         if r.status_code == 200:
@@ -349,12 +347,11 @@ class BaseImageUploader(object):
     @classmethod
     def _build_url(cls, url, path):
         netloc = url.netloc
-        insecure = netloc in cls.insecure_registries
         if netloc in cls.mirrors:
             mirror = cls.mirrors[netloc]
             return '%sv2%s' % (mirror, path)
         else:
-            if insecure:
+            if netloc in cls.insecure_registries:
                 scheme = 'http'
             else:
                 scheme = 'https'
@@ -408,6 +405,7 @@ class BaseImageUploader(object):
         tags_r.raise_for_status()
 
         manifest = manifest_r.json()
+
         digest = manifest_r.headers['Docker-Content-Digest']
         if manifest.get('schemaVersion', 2) == 1:
             config = json.loads(manifest['history'][0]['v1Compatibility'])
@@ -508,11 +506,11 @@ class BaseImageUploader(object):
 
         # prime self.insecure_registries by testing every image
         for url in image_urls:
-            self.is_insecure_registry(url.netloc)
+            self.is_insecure_registry(url)
 
         discover_args = []
         for image in images:
-            discover_args.append((image, tag_from_label))
+            discover_args.append((self, image, tag_from_label))
         p = futures.ThreadPoolExecutor(max_workers=16)
 
         versioned_images = {}
@@ -527,6 +525,7 @@ class BaseImageUploader(object):
         self.is_insecure_registry(image_url.netloc)
         session = self.authenticate(
             image_url, username=username, password=password)
+
         i = self._inspect(image_url, session)
         return self._discover_tag_from_inspect(i, image, tag_from_label,
                                                fallback_tag)
@@ -566,8 +565,17 @@ class BaseImageUploader(object):
         try:
             requests.get('https://%s/v2' % registry_host, timeout=30)
         except requests.exceptions.SSLError:
-            self.insecure_registries.add(registry_host)
-            return True
+            # Might be just a TLS certificate validation issue
+            # Just retry without the verification
+            try:
+                requests.get('https://%s/v2' % registry_host, timeout=30,
+                             verify=False)
+                self.no_verify_registries.add(registry_host)
+                return False
+            except requests.exceptions.SSLError:
+                # So nope, it's really not a certificate verification issue
+                self.insecure_registries.add(registry_host)
+                return True
         except Exception:
             # for any other error assume it is a secure registry, because:
             # - it is secure registry
@@ -615,129 +623,6 @@ class BaseImageUploader(object):
                 LOG.debug('%s %s' % (r.status_code, r.reason))
 
 
-class DockerImageUploader(BaseImageUploader):
-    """Upload images using docker pull/tag/push"""
-
-    def upload_image(self, task):
-        t = task
-        LOG.info('imagename: %s' % t.image_name)
-
-        if t.dry_run:
-            return []
-
-        if t.modify_role:
-            target_session = self.authenticate(
-                t.target_image_url)
-            if self._image_exists(t.target_image,
-                                  session=target_session):
-                LOG.warning('Skipping upload for modified image %s' %
-                            t.target_image)
-                return []
-        else:
-            source_session = self.authenticate(
-                t.source_image_url)
-            if self._images_match(t.source_image, t.target_image,
-                                  session1=source_session):
-                LOG.warning('Skipping upload for image %s' % t.image_name)
-                return []
-
-        dockerc = Client(base_url='unix://var/run/docker.sock', version='auto')
-        self._pull(dockerc, t.repo, tag=t.source_tag)
-
-        if t.modify_role:
-            self.run_modify_playbook(
-                t.modify_role, t.modify_vars, t.source_image,
-                t.target_image_source_tag, t.append_tag)
-            # raise an exception if the playbook didn't tag
-            # the expected target image
-            dockerc.inspect_image(t.target_image)
-        else:
-            response = dockerc.tag(
-                image=t.source_image, repository=t.target_image_no_tag,
-                tag=t.target_tag, force=True
-            )
-            LOG.debug(response)
-
-        self._push(dockerc, t.target_image_no_tag, tag=t.target_tag)
-
-        LOG.warning('Completed upload for image %s' % t.image_name)
-        if t.cleanup == CLEANUP_NONE:
-            return []
-        if t.cleanup == CLEANUP_PARTIAL:
-            return [t.source_image]
-        return [t.source_image, t.target_image]
-
-    @classmethod
-    @tenacity.retry(  # Retry up to 5 times with jittered exponential backoff
-        reraise=True,
-        wait=tenacity.wait_random_exponential(multiplier=1, max=10),
-        stop=tenacity.stop_after_attempt(5)
-    )
-    def _pull(cls, dockerc, image, tag=None):
-        LOG.info('Pulling %s' % image)
-
-        for line in dockerc.pull(image, tag=tag, stream=True):
-            status = json.loads(line)
-            if 'error' in status:
-                LOG.warning('docker pull failed: %s' % status['error'])
-                raise ImageUploaderException('Could not pull image %s' % image)
-
-    @classmethod
-    @tenacity.retry(  # Retry up to 5 times with jittered exponential backoff
-        reraise=True,
-        wait=tenacity.wait_random_exponential(multiplier=1, max=10),
-        stop=tenacity.stop_after_attempt(5)
-    )
-    def _push(cls, dockerc, image, tag=None):
-        LOG.info('Pushing %s' % image)
-
-        for line in dockerc.push(image, tag=tag, stream=True):
-            status = json.loads(line)
-            if 'error' in status:
-                LOG.warning('docker push failed: %s' % status['error'])
-                raise ImageUploaderException('Could not push image %s' % image)
-
-    def cleanup(self, local_images):
-        if not local_images:
-            return []
-
-        dockerc = Client(base_url='unix://var/run/docker.sock', version='auto')
-        for image in sorted(local_images):
-            if not image:
-                continue
-            LOG.warning('Removing local copy of %s' % image)
-            try:
-                dockerc.remove_image(image)
-            except docker.errors.APIError as e:
-                if e.explanation:
-                    LOG.error(e.explanation)
-                else:
-                    LOG.error(e)
-
-    def run_tasks(self):
-        if not self.upload_tasks:
-            return
-        local_images = []
-
-        # Pull a single image first, to avoid duplicate pulls of the
-        # same base layers
-        uploader, first_task = self.upload_tasks.pop()
-        result = uploader.upload_image(first_task)
-        local_images.extend(result)
-
-        # workers will be based on CPU count with a min 4, max 12
-        workers = min(12, max(4, processutils.get_worker_count()))
-        p = futures.ThreadPoolExecutor(max_workers=workers)
-
-        for result in p.map(upload_task, self.upload_tasks):
-            local_images.extend(result)
-        LOG.info('result %s' % local_images)
-
-        # Do cleanup after all the uploads so common layers don't get deleted
-        # repeatedly
-        self.cleanup(local_images)
-
-
 class SkopeoImageUploader(BaseImageUploader):
     """Upload images using skopeo copy"""
 
@@ -823,10 +708,12 @@ class SkopeoImageUploader(BaseImageUploader):
         LOG.info('Copying from %s to %s' % (source, target))
         cmd = ['skopeo', 'copy']
 
-        if source_url.netloc in cls.insecure_registries:
+        if source_url.netloc in [cls.insecure_registries,
+                                 cls.no_verify_registries]:
             cmd.append('--src-tls-verify=false')
 
-        if target_url.netloc in cls.insecure_registries:
+        if target_url.netloc in [cls.insecure_registries,
+                                 cls.no_verify_registries]:
             cmd.append('--dest-tls-verify=false')
 
         cmd.append(source)
@@ -913,7 +800,8 @@ class PythonImageUploader(BaseImageUploader):
             return []
 
         target_session = self.authenticate(
-            t.target_image_url)
+            t.target_image_url
+        )
 
         self._detect_target_export(t.target_image_url, target_session)
 
@@ -928,7 +816,8 @@ class PythonImageUploader(BaseImageUploader):
             copy_target_url = t.target_image_url
 
         source_session = self.authenticate(
-            t.source_image_url)
+            t.source_image_url
+        )
 
         manifest_str = self._fetch_manifest(
             t.source_image_url,
@@ -1099,7 +988,7 @@ class PythonImageUploader(BaseImageUploader):
     @tenacity.retry(  # Retry up to 5 times with jittered exponential backoff
         reraise=True,
         retry=tenacity.retry_if_exception_type(
-            requests.exceptions.RequestException
+            IOError
         ),
         wait=tenacity.wait_random_exponential(multiplier=1, max=10),
         stop=tenacity.stop_after_attempt(5)
@@ -1181,6 +1070,9 @@ class PythonImageUploader(BaseImageUploader):
                 target_session=target_session
             ))
         for job in copy_jobs:
+            e = job.exception()
+            if e:
+                raise e
             image = job.result()
             if image:
                 LOG.debug('Upload complete for layer: %s' % image)
@@ -1277,7 +1169,8 @@ class PythonImageUploader(BaseImageUploader):
         LOG.info('Pulling %s' % pull_source)
         cmd = ['podman', 'pull']
 
-        if source_url.netloc in cls.insecure_registries:
+        if source_url.netloc in [cls.insecure_registries,
+                                 cls.no_verify_registries]:
             cmd.append('--tls-verify=false')
 
         cmd.append(pull_source)
@@ -1666,10 +1559,10 @@ def upload_task(args):
 
 
 def discover_tag_from_inspect(args):
-    image, tag_from_label = args
-    image_url = BaseImageUploader._image_to_url(image)
-    session = BaseImageUploader.authenticate(image_url)
-    i = BaseImageUploader._inspect(image_url, session=session)
+    self, image, tag_from_label = args
+    image_url = self._image_to_url(image)
+    session = self.authenticate(image_url)
+    i = self._inspect(image_url, session=session)
     if ':' in image_url.path:
         # break out the tag from the url to be the fallback tag
         path = image.rpartition(':')
@@ -1677,5 +1570,5 @@ def discover_tag_from_inspect(args):
         image = path[0]
     else:
         fallback_tag = None
-    return image, BaseImageUploader._discover_tag_from_inspect(
+    return image, self._discover_tag_from_inspect(
         i, image, tag_from_label, fallback_tag)
